#pragma once

#include <BWAPI.h>
#include "CBase.h"
#include "CUnit.h"
#include "Macro.h"
#include "Util.h"

using namespace BWAPI;

class Analysis
{
public:
	static double analyze(BWAPI::TechType tech);
	static double analyze(BWAPI::UnitType unit);
	static double analyze(BWAPI::UpgradeType upgrade);
	static double analyzeDrone(double likelihoodToAttack);
	static double analyzeEvoChamber(double likelihoodToAttack);
	static double analyzeGas();
	static double analyzeHatchery(double likelihoodToAttack);
	static double analyzeHive();
	static double analyzeHydraDen();
	static double analyzeHydralisk(double likelihoodToAttack);
	static double analyzeLair();
	static double analyzeMutalisk();
	static double analyzeOverlord(double likelihoodToAttack);
	static double analyzeQueensNest();
	static double analyzeSpawningPool();
	static double analyzeSpire();
	static double analyzeSpore();
	static double analyzeSunken();
	static double analyzeUltraCavern();
	static double analyzeUltralisk();
	static double analyzeZergling();

	static double analyzeGroundArmor();
	static double analyzeHydraRange();
	static double analyzeHydraSpeed();
	static double analyzeLingSpeed();
	static double analyzeMissile();
	static double analyzeOverlordSpeed();
};